@@ -12,8 +12,22 @@
 #'   x = "cyl", y = "count"
 #' )
 #' @export
-#' @import ggplot2
 barplot_for_counts <- function(data = NULL, x, y) {
+  # check if Package 'ggplot2' is installed
+  if (!"ggplot2" %in% rownames(utils::installed.packages())) {
+    message(paste0(
+      "This function requires the installation of Package 'ggplot2'.",
+      "\nTo install Package 'ggplot2', type ",
+      "'kim::prep(ggplot2)'",
+      "\n\nAlternatively, to install all packages (dependencies) required ",
+      "for all\nfunctions in Package 'kim', type ",
+      "'kim::install_all_dependencies()'"))
+    return()
+  } else {
+    # proceed if Package 'ggplot2' is already installed
+    kim::prep("ggplot2")
+  }
+  # set data to be a data.table
   data <- data.table::setDT(copy(data))
   # check for x axis
   if (!is.null(data) & x %in% names(data) & y %in% names(data)) {
