@@ -12,8 +12,21 @@
 #' cum_percent_plot(mtcars$mpg)
 #' cum_percent_plot(vector= mtcars$mpg, output_type = "dt")
 #' @export
-#' @import ggplot2
 cum_percent_plot <- function(vector, output_type = "plot") {
+  # check if Package 'ggplot2' is installed
+  if (!"ggplot2" %in% rownames(utils::installed.packages())) {
+    message(paste0(
+      "This function requires the installation of Package 'ggplot2'.",
+      "\nTo install Package 'ggplot2', type ",
+      "'kim::prep(ggplot2)'",
+      "\n\nAlternatively, to install all packages (dependencies) required ",
+      "for all\nfunctions in Package 'kim', type ",
+      "'kim::install_all_dependencies()'"))
+    return()
+  } else {
+    # proceed if Package 'ggplot2' is already installed
+    kim::prep("ggplot2")
+  }
   # omit na
   v_no_na <- stats::na.omit(vector)
   freq_table <- kim::tabulate_vector(
