@@ -15,6 +15,8 @@
 #' @param y_axis_title_vjust position of the y axis title (default = 0.85).
 #' @param x_axis_title title for x axis (default = "Value")
 #' @param y_axis_title title for y axis (default = "Count")
+#' @param cap_axis_lines logical. Should the axis lines be capped at the
+#' outer tick marks? (default = FALSE)
 #' @param notify_na_count if \code{TRUE}, notify how many observations
 #' were removed due to missing values. By default, NA count will be printed
 #' only if there are any NA values.
@@ -27,7 +29,6 @@
 #' histogram(vector = mtcars[["mpg"]], x_tick_marks = seq(10, 36, 2),
 #' y_tick_marks = seq(0, 8, 2), y_axis_title_vjust = 0.5,
 #' y_axis_title = "Freq", x_axis_title = "Values of mpg")
-#' @import ggplot2
 #' @export
 histogram <- function(
   vector = NULL,
@@ -39,7 +40,22 @@ histogram <- function(
   y_axis_title_vjust = 0.85,
   x_axis_title = NULL,
   y_axis_title = NULL,
+  cap_axis_lines = FALSE,
   notify_na_count = NULL) {
+  # check if Package 'ggplot2' is installed
+  if (!"ggplot2" %in% rownames(utils::installed.packages())) {
+    message(paste0(
+      "This function requires the installation of Package 'ggplot2'.",
+      "\nTo install Package 'ggplot2', type ",
+      "'kim::prep(ggplot2)'",
+      "\n\nAlternatively, to install all packages (dependencies) required ",
+      "for all\nfunctions in Package 'kim', type ",
+      "'kim::install_all_dependencies()'"))
+    return()
+  } else {
+    # proceed if Package 'ggplot2' is already installed
+    kim::prep("ggplot2")
+  }
   # bind the vars locally to the function
   value <- bins <- NULL
   # deal with NA values
@@ -103,6 +119,8 @@ histogram <- function(
   } else {
     g1 <- g1 + ylab("Count")
   }
-  g1 <- g1 + theme_kim(y_axis_title_vjust = y_axis_title_vjust)
+  g1 <- g1 + theme_kim(
+    y_axis_title_vjust = y_axis_title_vjust,
+    cap_axis_lines = cap_axis_lines)
   return(g1)
 }
