@@ -5,8 +5,10 @@
 #' The current version of the package only supports a simple mediation
 #' model consisting of one independent variable, one mediator variable,
 #' and one dependent variable.
-#' Uses the source code from 'mediation' package v4.5.0,
-#' Tingley et al. (2019)
+#'
+#' This function requires installing Package 'mediation' v4.5.0
+#' (or possibly a higher version) by Tingley et al. (2019),
+#' and uses the source code from a function in the package.
 #' <https://cran.r-project.org/package=mediation>
 #'
 #' @param data a data object (a data frame or a data.table)
@@ -64,6 +66,21 @@ mediation_analysis <- function(
   sigfigs = 3,
   output_type = "summary_dt",
   silent = FALSE) {
+  # check if Package 'mediation' is installed
+  if (!"mediation" %in% rownames(utils::installed.packages())) {
+    message(paste0(
+      "To conduct a mediation analysis, Package 'mediation' must ",
+      "be installed.\nTo install Package 'mediation', type ",
+      "'kim::prep(mediation)'",
+      "\n\nAlternatively, to install all packages (dependencies) required ",
+      "for all\nfunctions in Package 'kim', type ",
+      "'kim::install_all_dependencies()'"))
+    return()
+  } else {
+    # proceed if Package 'mediation' is already installed
+    mediate_fn_from_mediation <- utils::getFromNamespace(
+      "mediate", "mediation")
+  }
   # check number of variables entered
   if (any(lengths(list(iv_name, mediator_name, dv_name)) > 1)) {
     stop(paste0(
@@ -81,12 +98,19 @@ mediation_analysis <- function(
       "slow running time.\n"
     ))
   }
+  # omit na values
+  dt <- data.table::setDT(data.table::copy(data))[
+    !is.na(get(iv_name)) & !is.na(get(mediator_name)) &
+      !is.na(get(dv_name))
+  ]
+  # build formulas
   med_model_formula <- stats::as.formula(paste0(
     mediator_name, " ~ ", iv_name
   ))
   outcome_model_formula <- stats::as.formula(paste0(
     dv_name, " ~ ", mediator_name, " + ", iv_name
   ))
+  # add covariates
   if (!is.null(covariates_names)) {
     med_model_formula <- paste0(
       mediator_name, " ~ ", iv_name, " + ",
@@ -99,13 +123,13 @@ mediation_analysis <- function(
   }
   med_model <- stats::lm(
     formula = med_model_formula,
-    data = data
+    data = dt
   )
   outcome_model <- stats::lm(
-    formula = outcome_model_formula, data = data
+    formula = outcome_model_formula, data = dt
   )
   # x: full model after mediation analysis
-  x <- mediation::mediate(
+  x <- mediate_fn_from_mediation(
     model.m = med_model,
     model.y = outcome_model,
     sims = iterations,
