@@ -1,4 +1,13 @@
-#' Summarize multiple regression results in a data.table
+#' Multiple regression
+#'
+#' Conduct multiple regression analysis and summarize the results
+#' in a data.table.
+#'
+#' To include standardized beta(s) in the regression results table,
+#' the following package(s) must be installed prior to running the function:
+#' Package 'lm.beta' v1.5-1 (or possibly a higher version) by
+#' Stefan Behrendt (2014),
+#' <https://cran.r-project.org/package=lm.beta>
 #'
 #' @param data a data object (a data frame or a data.table)
 #' @param formula a formula object for the regression equation
@@ -14,6 +23,20 @@ multiple_regression <- function(
   formula = NULL,
   sigfigs = NULL,
   round_digits_after_decimal = NULL) {
+  # check if Package 'lm.beta' is installed
+  if (!"lm.beta" %in% rownames(utils::installed.packages())) {
+    message(paste0(
+      "To include standardized betas, Package 'lm.beta' must ",
+      "be installed.\nTo install Package 'lm.beta', type ",
+      "'kim::prep(lm.beta)'",
+      "\n\nAlternatively, to install all packages (dependencies) required ",
+      "for all\nfunctions in Package 'kim', type ",
+      "'kim::install_all_dependencies()'"))
+  } else {
+    # proceed if Package 'lm.beta' is already installed
+    lm_beta_fn_from_lm_beta <- utils::getFromNamespace(
+      "lm.beta", "lm.beta")
+  }
   # regression model
   model <- stats::lm(formula = formula, data = data)
   model_summary <- summary(model)
@@ -23,19 +46,24 @@ multiple_regression <- function(
   estimate <- reg_results[, "Estimate"]
   se <- reg_results[, "Std. Error"]
   t_stat <- reg_results[, "t value"]
-  p_value <- pretty_round_p_value(reg_results[, "Pr(>|t|)"])
+  p_value <- kim::pretty_round_p_value(reg_results[, "Pr(>|t|)"])
   r_squared <- model_summary[["r.squared"]]
   adj_r_squared <- model_summary[["adj.r.squared"]]
   df_model <- model_summary[["fstatistic"]][["numdf"]]
   df_residual <- model_summary[["fstatistic"]][["dendf"]]
   f_stat <- model_summary[["fstatistic"]][["value"]]
-  model_p_value <- pretty_round_p_value(
+  model_p_value <- kim::pretty_round_p_value(
     stats::pf(f_stat, df_model, df_residual, lower.tail = FALSE),
     include_p_equals = TRUE
   )
   n <- nrow(stats::model.frame(model))
-  # standardized betas
-  std_beta <- lm.beta::lm.beta(model)[["standardized.coefficients"]]
+  # calculate standardized betas if lm.beta package is already installed
+  if ("lm.beta" %in% rownames(utils::installed.packages())) {
+    std_beta <- lm_beta_fn_from_lm_beta(model)[[
+      "standardized.coefficients"]]
+  } else {
+    std_beta <- rep(NA, length(estimate))
+  }
   # rounding
   if (!is.null(sigfigs) & !is.null(round_digits_after_decimal)) {
     stop(paste0(
