@@ -131,7 +131,7 @@ prep <- function(
   # packages that failed to install
   if (length(pkg_that_failed_to_install) > 0) {
     message(paste0(
-      "\nThe following package(s) failed to install:\n",
+      "The following package(s) failed to install:\n",
       paste(pkg_that_failed_to_install, collapse = ", "), "\n"
     ))
   }
@@ -141,14 +141,14 @@ prep <- function(
   )
   if (length(pkg_that_failed_to_load) > 0) {
     message(paste0(
-      "\nThe following package(s) failed to load:\n",
+      "The following package(s) failed to load:\n",
       paste(pkg_that_failed_to_load, collapse = ", "), "\n"
     ))
   }
   # newly installed packages
   if (length(newly_installed_pkg) > 0) {
     message(paste0(
-      "\nThe following package(s) were newly installed:\n",
+      "The following package(s) were newly installed:\n",
       paste(newly_installed_pkg, collapse = ", "), "\n"
     ))
   }
@@ -159,7 +159,7 @@ prep <- function(
   if (length(loaded_pkg_final) > 0) {
     if (silent_if_successful == FALSE) {
       message(paste0(
-        "\nThe following package(s) were successfully loaded:\n",
+        "The following package(s) were successfully loaded:\n",
         paste(loaded_pkg_final, collapse = ", "), "\n"
       ))
     }
